searchData={"items":[{"type":"task","title":"mix orbit.gen.cert","doc":"Create a self-signed certificate.\n\n    $ mix orbit.gen.cert [hostname]\n\nThe `hostname` is optional and defaults to \"localhost\".\n\nThe following files will be created:\n\n- `priv/tls/ .crt` - the certificate\n- `priv/tls/ .key` - the private key","ref":"Mix.Tasks.Orbit.Gen.Cert.html"},{"type":"task","title":"mix orbit.init","doc":"Initialize an Orbit capsule.\n\n    $ mix orbit.init OTP_APP MODULE\n\nThe `OTP_APP` argument is the name of the existing OTP application under which the capsule will be hosted, e.g. `my_app`.\n\nThe `MODULE` argument is the namespace under which the capsule files will be generated, e.g. `MyAppCapsule`.","ref":"Mix.Tasks.Orbit.Init.html"},{"type":"task","title":"Example - mix orbit.init","doc":"$ mix orbit.init my_app MyAppCapsule","ref":"Mix.Tasks.Orbit.Init.html#module-example"},{"type":"task","title":"mix orbit.server","doc":"Run the Orbit server.\n\n    $ mix orbit.server","ref":"Mix.Tasks.Orbit.Server.html"},{"type":"module","title":"Orbit","doc":"A simple framework for a simple protocol.\n\nOrbit is a framework for building [Gemini](https://geminiprotocol.net/) applications, known as \"capsules\".\n\nThis framework focuses primarily on the Gemini protocol itself, intent on getting a request into your application,\nhandling it, and sending a Gemtext response.\n\nIt doesn't make any assumptions about your business logic, backing database, migrations, or anything like that.\nIf you need a database, you can add it manually ([see below](#module-adding-a-database)).","ref":"Orbit.html"},{"type":"module","title":"Concepts - Orbit","doc":"Orbit borrows a lot of ideas from Plug and Phoenix.\n\n  - `Orbit.Endpoint` - the TLS server that accepts incoming requests (`Phoenix.Endpoint` + `cowboy`)\n  - `Orbit.Request` - encapsulates the request-response lifecyle (`Plug.Conn`)\n  - `Orbit.Pipe` - the behaviour for request middleware (`Plug`)\n  - `Orbit.Router` - defines pipelines and routes (`Phoenix.Router`)\n  - `Orbit.Controller` - processes requests (`Phoenix.Controller`)\n  - `Orbit.Gemtext` - renders Gemtext templates (`Phoenix.Component`)\n\nSome additional niceties:\n\n  - `Orbit.Static` - serves up files from `priv/statc` (`Plug.Static`)\n  - `Orbit.Status` - a canonical list of all status codes\n  - `Orbit.ClientCertificate` - extracts client certificates from the request","ref":"Orbit.html#module-concepts"},{"type":"module","title":"Conventions - Orbit","doc":"A basic Orbit application is structured as follows.\n\n- `MyApp` - the main application business logic\n- `MyAppCapsule` - the namespace for the Gemini app\n- `MyAppCapsule.Endpoint` - the combined TLS server and router\n- `MyAppCapsule.LayoutGmi` - layout templates\n- `MyAppCapsule.PageController` - a basic controller\n- `MyAppCapsule.PageGmi` - templates for that controller","ref":"Orbit.html#module-conventions"},{"type":"module","title":"Quickstart - Orbit","doc":"Orbit does not have a fancy project generator like `mix phx.new`. Instead, you add the dependency to a new\n(or existing!) application, and then run `mix orbit.init` to get started.\n\nCreate a new application:\n\n    $ mix new my_app --sup\n\nAdd the dependency:\n\n    # mix.exs\n    def deps do\n      [\n        {:orbit, \"~> 0.3.0\"}\n      ]\n    end\n\nGenerate some files (don't worry, existing files won't be modified):\n\n    $ mix deps.get\n    $ mix orbit.init my_app MyAppCapsule\n\nFollow the instructions from the task's output.\n\nFinally, start the application and visit `gemini://localhost/`","ref":"Orbit.html#module-quickstart"},{"type":"module","title":"Adding a Database - Orbit","doc":"This example for setting up Postgres was cribbed from the [Ecto](https://hexdocs.pm/ecto/Ecto.html) docs. You might\nprefer [SQLite](https://hexdocs.pm/ecto_sqlite3/Ecto.Adapters.SQLite3.html) as an alternative.\n\nAdd the dependencies:\n\n    # mix.exs\n    def deps do\n      [\n        # Check hex.pm for the latest versions!\n        {:ecto, \"~> 3.11.2\"},\n        {:ecto_sql, \"~> 3.11.1\"},\n        {:postgrex, \"~> 0.17.5\"}\n      ]\n    end\n\nAdd some config:\n\n    # config/config.exs\n    config :my_app, ecto_repos: [MyApp.Repo]\n\n    # config/runtime.exs\n    config :my_app, MyApp.Repo, url: System.fetch_env!(\"DATABASE_URL\")\n\nCreate the repo module:\n\n    # lib/my_app/repo.ex\n    defmodule MyApp.Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.Postgres\n    end\n\nAdd the repo to the supervision tree:\n\n    # lib/application.ex\n    children = [\n      MyApp.Repo\n    ]\n\nFinally, create the DB.\n\n    $ mix ecto.create\n\nMigrations can be generated with `mix ecto.gen.migration`, and schemas are written by hand.","ref":"Orbit.html#module-adding-a-database"},{"type":"module","title":"Orbit.ClientCertificate","doc":"Commonly-used fields from the TLS client certificate.\n\nThe original `:OTPCertificate` record is available in the `otp_certificate` field. The [X509](https://hexdocs.pm/x509/)\nlibrary is included and can be used to extract additional values from the `otp_certificate`.","ref":"Orbit.ClientCertificate.html"},{"type":"module","title":"Fields - Orbit.ClientCertificate","doc":"- `common_name` - the common name (CN) string\n- `fingerprints` - a map of binary fingerprints for various hash algorithms\n  - `:sha` for SHA-1\n  - `:sha256` for SHA-256\n- `not_valid_after` - the UTC `DateTime` at the end of validity\n- `not_valid_before` - the UTC `DateTime` at the beginning of validity\n- `otp_certificate` - the underlying `:OTPCertificate` record\n- `self_signed?` - if the certificate has been self-signed (issuer is the same as the subject)\n- `serial_number` - the serial number integer","ref":"Orbit.ClientCertificate.html#module-fields"},{"type":"function","title":"Orbit.ClientCertificate.from_der/1","doc":"Returns a new `%ClientCertificate{}` from a DER-encoded binary.","ref":"Orbit.ClientCertificate.html#from_der/1"},{"type":"type","title":"Orbit.ClientCertificate.t/0","doc":"","ref":"Orbit.ClientCertificate.html#t:t/0"},{"type":"behaviour","title":"Orbit.Pipe","doc":"The interface for request middleware.\n\nPipes are analogous to the behaviour of `Plug`. Requests enter the `Orbit.Endpoint` and are passed through a series of pipes\nthat sequentially process the request, and at the end of the pipeline the response is sent to the client.\n\nA pipe may also be simple 2-arity anonymous function that implements the same typespec as `c:call/2`.\n\nWhen you `use Orbit.Router` or `use Orbit.Controller`, the `c:call/2` callback is injected into the module,\nturning it into a Pipe.","ref":"Orbit.Pipe.html"},{"type":"callback","title":"Orbit.Pipe.call/2","doc":"Handle a request.\n\nTakes in a a Request, potentially modifies it, and returns a Request. The `arg` can be any value and is\nPipe-dependenent.","ref":"Orbit.Pipe.html#c:call/2"},{"type":"function","title":"Orbit.Pipe.call/3","doc":"Trigger a pipe.","ref":"Orbit.Pipe.html#call/3"},{"type":"module","title":"Orbit.Request","doc":"Encapsulate the request-response cycle.\n\nAnalogous to `%Plug.Conn{}`.","ref":"Orbit.Request.html"},{"type":"module","title":"Request Fields - Orbit.Request","doc":"- `client_cert` - an `Orbit.ClientCertificate` for the client TLS certificate, if provided\n- `params` - combined request parameters from the URI and query params\n  - bare query strings (e.g. `\"?foo\"`) are assigned to the `\"_query\"` key\n- `uri` - the parsed request `URI` struct","ref":"Orbit.Request.html#module-request-fields"},{"type":"module","title":"Response Fields - Orbit.Request","doc":"- `body` - the response body; may be an iolist or a stream\n- `halted?` - if the current response pipeline should be stopped prematurely\n- `meta` - the response meta field; its meaning depends on the status code\n- `status` - the response status code, may be an integer or an atom (see `Orbit.Status`)\n- `sent?` - if the response has been transmitted back to the client","ref":"Orbit.Request.html#module-response-fields"},{"type":"module","title":"Application Fields - Orbit.Request","doc":"- `assigns` - a generic map of application-defined data to be manipulated and rendered\n- `private` - a generic map of library-defined data that should not be accessed by end-users","ref":"Orbit.Request.html#module-application-fields"},{"type":"function","title":"Orbit.Request.assign/2","doc":"Sets multiple assigns on the request.","ref":"Orbit.Request.html#assign/2"},{"type":"function","title":"Orbit.Request.assign/3","doc":"Sets a single assign on the request.","ref":"Orbit.Request.html#assign/3"},{"type":"function","title":"Orbit.Request.bad_request/2","doc":"Responds with a :bad_request status.","ref":"Orbit.Request.html#bad_request/2"},{"type":"function","title":"Orbit.Request.certificate_not_authorized/2","doc":"Responds with a :certificate_not_authorized status.","ref":"Orbit.Request.html#certificate_not_authorized/2"},{"type":"function","title":"Orbit.Request.certificate_not_valid/2","doc":"Responds with a :certificate_not_valid status.","ref":"Orbit.Request.html#certificate_not_valid/2"},{"type":"function","title":"Orbit.Request.cgi_error/2","doc":"Responds with a :cgi_error status.","ref":"Orbit.Request.html#cgi_error/2"},{"type":"function","title":"Orbit.Request.client_certificate_required/2","doc":"Responds with a :client_certificate_required status.","ref":"Orbit.Request.html#client_certificate_required/2"},{"type":"function","title":"Orbit.Request.gone/2","doc":"Responds with a :gone status.","ref":"Orbit.Request.html#gone/2"},{"type":"function","title":"Orbit.Request.halt/1","doc":"Stops the request pipeline from further execution.","ref":"Orbit.Request.html#halt/1"},{"type":"function","title":"Orbit.Request.input/2","doc":"Responds with a :input status.","ref":"Orbit.Request.html#input/2"},{"type":"function","title":"Orbit.Request.not_found/2","doc":"Responds with a :not_found status.","ref":"Orbit.Request.html#not_found/2"},{"type":"function","title":"Orbit.Request.permanent_failure/2","doc":"Responds with a :permanent_failure status.","ref":"Orbit.Request.html#permanent_failure/2"},{"type":"function","title":"Orbit.Request.proxy_error/2","doc":"Responds with a :proxy_error status.","ref":"Orbit.Request.html#proxy_error/2"},{"type":"function","title":"Orbit.Request.proxy_request_refused/2","doc":"Responds with a :proxy_request_refused status.","ref":"Orbit.Request.html#proxy_request_refused/2"},{"type":"function","title":"Orbit.Request.put_body/2","doc":"Puts the body for a successful response.\n\nThe MIME type is specified via the `meta` argument of `put_status/3`.","ref":"Orbit.Request.html#put_body/2"},{"type":"function","title":"Orbit.Request.put_private/3","doc":"Sets a single private value on the request.","ref":"Orbit.Request.html#put_private/3"},{"type":"function","title":"Orbit.Request.put_status/3","doc":"Puts the status and metadata for a response.\n\nIf the status code is non-successful, then the response body will be ignored and not sent to the client.\n\nThe status can be an integer or an atom. See `Orbit.Status` for a list of applicable status codes and\nconvenience functions.","ref":"Orbit.Request.html#put_status/3"},{"type":"function","title":"Orbit.Request.redirect_permanent/2","doc":"Responds with a :redirect_permanent status.","ref":"Orbit.Request.html#redirect_permanent/2"},{"type":"function","title":"Orbit.Request.redirect_temporary/2","doc":"Responds with a :redirect_temporary status.","ref":"Orbit.Request.html#redirect_temporary/2"},{"type":"function","title":"Orbit.Request.sensitive_input/2","doc":"Responds with a :sensitive_input status.","ref":"Orbit.Request.html#sensitive_input/2"},{"type":"function","title":"Orbit.Request.server_unavailable/2","doc":"Responds with a :server_unavailable status.","ref":"Orbit.Request.html#server_unavailable/2"},{"type":"function","title":"Orbit.Request.slow_down/2","doc":"Responds with a :slow_down status.","ref":"Orbit.Request.html#slow_down/2"},{"type":"function","title":"Orbit.Request.success/2","doc":"Responds with a :success status.","ref":"Orbit.Request.html#success/2"},{"type":"function","title":"Orbit.Request.temporary_failure/2","doc":"Responds with a :temporary_failure status.","ref":"Orbit.Request.html#temporary_failure/2"},{"type":"type","title":"Orbit.Request.t/0","doc":"","ref":"Orbit.Request.html#t:t/0"},{"type":"module","title":"Orbit.Status","doc":"The canonical list of response status codes.\n\nThis module contains helper functions for applying any status code to an `Orbit.Request`.\n\nWhen set manually, status codes may be specified by integer or atom. They can be coerced one way or the other\nwith `to_atom/1` and `to_integer/1`.\n\n| Status | Name |\n| ---- | ---- |\n| 10 | `:input` |\n| 11 | `:sensitive_input` |\n| 20 | `:success` |\n| 30 | `:redirect_temporary` |\n| 31 | `:redirect_permanent` |\n| 40 | `:temporary_failure` |\n| 41 | `:server_unavailable` |\n| 42 | `:cgi_error` |\n| 43 | `:proxy_error` |\n| 44 | `:slow_down` |\n| 50 | `:permanent_failure` |\n| 51 | `:not_found` |\n| 52 | `:gone` |\n| 53 | `:proxy_request_refused` |\n| 59 | `:bad_request` |\n| 60 | `:client_certificate_required` |\n| 61 | `:certificate_not_authorized` |\n| 62 | `:certificate_not_valid` |","ref":"Orbit.Status.html"},{"type":"function","title":"Orbit.Status.statuses/0","doc":"Returns a map of all status codes with atom keys.","ref":"Orbit.Status.html#statuses/0"},{"type":"function","title":"Orbit.Status.to_atom/1","doc":"Normalizes a status code to an atom.","ref":"Orbit.Status.html#to_atom/1"},{"type":"function","title":"Orbit.Status.to_integer/1","doc":"Normalizes a status code to an integer.","ref":"Orbit.Status.html#to_integer/1"},{"type":"type","title":"Orbit.Status.t/0","doc":"","ref":"Orbit.Status.html#t:t/0"},{"type":"module","title":"Orbit.Controller","doc":"Process requests and render responses.","ref":"Orbit.Controller.html"},{"type":"module","title":"Options - Orbit.Controller","doc":"None.","ref":"Orbit.Controller.html#module-options"},{"type":"module","title":"Usage - Orbit.Controller","doc":"The `use Orbit.Controller` macro injects the following into the module:\n\n    @behaviour Orbit.Pipe\n    def call(request, arg)\n    def action(request, action) # overridable\n\nThe `call/2` function implements the `Orbit.Pipe` callback, making the controller behave like any other pipe. The\n`arg` is the action name, as an atom, and is set to the `:action` assign. Any `pipe/2` definitions in this\ncontroller are called first, and then `action/2` is called.","ref":"Orbit.Controller.html#module-usage"},{"type":"module","title":"Overriding `action/2` - Orbit.Controller","doc":"The `action/2` function is overridable. It's an easy way to extend the controller's default behavior, or to customize\nthe signature of the action functions to something other than `action_name(req, params)`. Its default implementation is:\n\n    def action(req, action) do\n      apply(__MODULE__, action, [req, req.params])\n    end","ref":"Orbit.Controller.html#module-overriding-action-2"},{"type":"module","title":"Views - Orbit.Controller","doc":"A controller can render responses directly in the controller action, or defer the rendering to an external view\nmodule. Define the `view/1` pipe to set the view template based on the controller action name.\n\n      view MyApp.MyView\n\n      def index(req, _params) do\n        render(req) # => MyApp.MyView.index(req.assigns)\n      end","ref":"Orbit.Controller.html#module-views"},{"type":"module","title":"Layouts - Orbit.Controller","doc":"Layouts are simply templates that are provided an `@inner_content` assign which contains the content of the child view\nto render within the layout.\n\n    def outer_layout(assigns) do\n      ~G\"\"\"\n      begin outer\n      <%= @inner_content %>\n      end outer\n      \"\"\"\n    end\n\n    req\n    |> put_layout(&outer_layout/1)\n    |> render()\n\n    # =>\n    \"\"\"\n    begin outer\n    ...view...\n    end outer\n    \"\"\"","ref":"Orbit.Controller.html#module-layouts"},{"type":"module","title":"Example - Orbit.Controller","doc":"# Router\n    route \"/users\", MyApp.UserController, :index\n    route \"/users/:id\", MyApp.UserController, :show\n\n    # Controller\n    defmodule MyApp.UserController do\n      use Orbit.Controller\n\n      view MyApp.UserView\n\n      def index(req, _params), do: ...\n      def show(req, %{\"id\" => id}), do: ...\n    end","ref":"Orbit.Controller.html#module-example"},{"type":"function","title":"Orbit.Controller.get_layout/1","doc":"Returns a list of all layouts.","ref":"Orbit.Controller.html#get_layout/1"},{"type":"function","title":"Orbit.Controller.get_template/1","doc":"Gets the Gemtext template to be rendered.","ref":"Orbit.Controller.html#get_template/1"},{"type":"function","title":"Orbit.Controller.gmi/2","doc":"Puts Gemtext content as the body of a successful response.","ref":"Orbit.Controller.html#gmi/2"},{"type":"macro","title":"Orbit.Controller.pipe/2","doc":"Define a pipe to run in the controller prior to the action.","ref":"Orbit.Controller.html#pipe/2"},{"type":"function","title":"Orbit.Controller.put_layout/2","doc":"Sets the layout view.\n\nLayouts receive an `@inner_content` assign that contains the content of the child view to render within the layout.\n\nThis is typically used directly in a router as a pipe, e.g.\n\n    pipe &Orbit.Controller.put_layout/2, &MyApp.LayoutView.main/1}","ref":"Orbit.Controller.html#put_layout/2"},{"type":"function","title":"Orbit.Controller.put_template/2","doc":"Puts the Gemtext view to be rendered.","ref":"Orbit.Controller.html#put_template/2"},{"type":"function","title":"Orbit.Controller.render/1","doc":"Renders the Gemtext view and layouts as a successful response.","ref":"Orbit.Controller.html#render/1"},{"type":"function","title":"Orbit.Controller.send_file/3","doc":"Sends a file as a binary stream.","ref":"Orbit.Controller.html#send_file/3"},{"type":"function","title":"Options - Orbit.Controller.send_file/3","doc":"- `:mime_type` - the MIME type of the file; if unspecified, it is determined from the file extension","ref":"Orbit.Controller.html#send_file/3-options"},{"type":"macro","title":"Orbit.Controller.view/1","doc":"Sets the view module for rendering controller actions.\n\nThe template is based on the controller action name.","ref":"Orbit.Controller.html#view/1"},{"type":"module","title":"Orbit.Endpoint","doc":"The main endpoint supervisor.","ref":"Orbit.Endpoint.html"},{"type":"module","title":"Usage - Orbit.Endpoint","doc":"Define the module:\n\n    # lib/my_app_capsule/endpoint.ex\n    defmodule MyAppCapsule.Endpoint do\n      use Orbit.Endpoint, otp_app: :my_app\n      use Orbit.Router\n\n      # ...define pipes and routes (see Orbit.Router docs)...\n    end\n\nThen add config:\n\n    # config/config.exs\n    config :my_app, MyAppCapsule.Endpoint,\n      certfile: \"path/to/hostname.crt\",\n      keyfile: \"path/to/hostname.key\"\n\nFinally, add it to the supervision tree:\n\n    # lib/my_app/application.ex\n    children = [\n      MyAppCapsule.Endpoint\n    ]","ref":"Orbit.Endpoint.html#module-usage"},{"type":"module","title":"Options for `use Orbit.Endpoint` - Orbit.Endpoint","doc":"","ref":"Orbit.Endpoint.html#module-options-for-use-orbit-endpoint"},{"type":"module","title":"Required - Orbit.Endpoint","doc":"- `:otp_app` - the OTP application name","ref":"Orbit.Endpoint.html#module-required"},{"type":"module","title":"Optional - Orbit.Endpoint","doc":"- `:entrypoint` - the initial pipe to handle incoming requests; defaults to the calling module","ref":"Orbit.Endpoint.html#module-optional"},{"type":"module","title":"Configuration - Orbit.Endpoint","doc":"","ref":"Orbit.Endpoint.html#module-configuration"},{"type":"module","title":"Required - Orbit.Endpoint","doc":"- One of:\n  - `:certfile` - path to a TLS certificatefile in the PEM format\n  - `:cert` - a DER-encoded certificate binary\n  - `:cert_pem` - a PEM-encoded certificate binary\n\n- One of:\n  - `:keyfile` - path to a TLS private key file in the PEM format\n  - `:key` - a DER-encoded private key binary\n  - `:key_pem` - a PEM-encoded private key binary","ref":"Orbit.Endpoint.html#module-required"},{"type":"module","title":"Optional - Orbit.Endpoint","doc":"- `:ip` - the IP to listen on; defaults to `\"0.0.0.0\"`\n- `:port` - the port to listen on; defaults to `1965`\n- `:debug_errors` - if true, returns stack traces for server errors; defaults to `false`","ref":"Orbit.Endpoint.html#module-optional"},{"type":"function","title":"Orbit.Endpoint.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Orbit.Endpoint.html#child_spec/1"},{"type":"function","title":"Orbit.Endpoint.listener_info/1","doc":"Returns metadata about the capsule's TLS listener.","ref":"Orbit.Endpoint.html#listener_info/1"},{"type":"function","title":"Orbit.Endpoint.start_link/1","doc":"Starts the Capsule supervisor.","ref":"Orbit.Endpoint.html#start_link/1"},{"type":"module","title":"Orbit.Gemtext","doc":"Render Gemtext content.\n\nA **template** is any 1-arity function that accepts an `assigns` map and returns a string of rendered Gemtext.\n\nA **view** is a module containing template functions.\n\nTemplates can be defined directly as functions, or embedded from `.gmi.eex` files into view module via `embed_templates/1`.\n\nEEx templates can be precompiled with `sigil_G/2`, as long as an `assigns` variable is in-scope.","ref":"Orbit.Gemtext.html"},{"type":"module","title":"Usage - Orbit.Gemtext","doc":"Add the imports to the view module:\n\n    import Orbit.Gemtext","ref":"Orbit.Gemtext.html#module-usage"},{"type":"module","title":"Examples - Orbit.Gemtext","doc":"","ref":"Orbit.Gemtext.html#module-examples"},{"type":"module","title":"Importing templates from a directory - Orbit.Gemtext","doc":"defmodule MyAppCapsule.PostGmi do\n      import Orbit.Gemtext\n\n      embed_templates \"post_gmi/*\"\n    end","ref":"Orbit.Gemtext.html#module-importing-templates-from-a-directory"},{"type":"module","title":"Writing templates directly - Orbit.Gemtext","doc":"defmodule MyAppCapsule.PostGmi do\n      import Orbit.Gemtext\n\n      def list(assigns) do\n        ~G\"\"\"\n        <%= for item <- @items do %>\n        * <%= item %>\n        <% end %>\n        \"\"\"\n      end\n    end","ref":"Orbit.Gemtext.html#module-writing-templates-directly"},{"type":"macro","title":"Orbit.Gemtext.embed_templates/1","doc":"Precompile template functions from external files.\n\nEvery file found in the wildcard `path` is compiled as EEx and injected as a template function into the view\nmodule, using the file basename as the function name. For example, `index.gmi.eex` will be defined as\n`def index(assigns)`.","ref":"Orbit.Gemtext.html#embed_templates/1"},{"type":"macro","title":"Orbit.Gemtext.render/3","doc":"Renders a template.\n\nThe `assigns` and `block` arguments are optional.\n\nIf a block is passed, its contents set to `@inner_content` assign of the template.","ref":"Orbit.Gemtext.html#render/3"},{"type":"macro","title":"Examples - Orbit.Gemtext.render/3","doc":"<%= render &my_template/1 %>\n\n    <%= render &my_template/1, title: @title %>\n\n    <%= render &my_template/1 do %>\n      inner content here\n    <% end %>","ref":"Orbit.Gemtext.html#render/3-examples"},{"type":"macro","title":"Orbit.Gemtext.sigil_G/2","doc":"Sigil for defining Gemtext content.\n\nThe `assigns` map must be in-scope.\n\nA single trailing newline character `\\n` will be trimmed, if it exists.","ref":"Orbit.Gemtext.html#sigil_G/2"},{"type":"macro","title":"Example - Orbit.Gemtext.sigil_G/2","doc":"def hello(assigns) do\n      ~G\"\"\"\n      Why hello there, <%= @name %>!\n      \"\"\"\n    end","ref":"Orbit.Gemtext.html#sigil_G/2-example"},{"type":"module","title":"Orbit.Router","doc":"Sort out incoming requests.","ref":"Orbit.Router.html"},{"type":"module","title":"Usage - Orbit.Router","doc":"`use Orbit.Router` injects the following into the module:\n\n    import Orbit.Router\n\n    def call(req, arg)","ref":"Orbit.Router.html#module-usage"},{"type":"module","title":"Example - Orbit.Router","doc":"defmodule MyAppCapsule.Endpoint do\n      use Orbit.Endpoint, otp_app: :my_app\n      use Orbit.Router\n\n      pipe &Orbit.Controller.put_layout/2, &MyAppCapsule.LayoutView.main/1\n      pipe MyAppCapsule.SetCurrentUser\n\n      route \"/static/*path\", Orbit.Static, from: :my_app\n\n      group do\n        pipe MyAppCapsule.RequireCurrentUser\n\n        route \"/messages\", MyAppCapsule.MessageController, :index\n        route \"/messages/:id\", MyAppCapsule.MessageController, :show\n      end\n    end","ref":"Orbit.Router.html#module-example"},{"type":"macro","title":"Orbit.Router.group/1","doc":"Defines a group of routes with a shared pipeline.\n\nGroups have their own pipelines that append any existing pipes from parent groups, or from the router. Groups\ncan be nested.","ref":"Orbit.Router.html#group/1"},{"type":"macro","title":"Example - Orbit.Router.group/1","doc":"pipe SetCurrentUser\n\n    route \"/\", HomeController, :show\n    # ...more routes for all users...\n\n    group do\n      pipe RequireUser\n\n      route \"/profile\", ProfileController, :show\n      # ...more routes for authenticated users...\n\n      group do\n        pipe RequireAdminRole\n\n        route \"/admin/users\", UserController, :index\n        # ...more routes for authenticated admin users...\n      end\n    end","ref":"Orbit.Router.html#group/1-example"},{"type":"macro","title":"Orbit.Router.pipe/2","doc":"Defines a pipe through which requests are processed.\n\nThe `pipe` argument may be either:\n\n- a module that implements `Orbit.Pipe`\n- a function capture of a 2-arity function\n\nIf the pipe halts the request, the router does not process any further pipes or route matches.","ref":"Orbit.Router.html#pipe/2"},{"type":"macro","title":"Orbit.Router.route/3","doc":"Defines a route that sends a request to a designated pipe.\n\nPath segments can contain parameters which are merged into the `params` field of the request. A wildcard parameter\ncan exist at the very end of a path match.\n\n    route \"/users/:id/edit\", UserController, :edit # => %{\"id\" => \"123\"}\n    route \"/posts/*slug\", PostController, :show # => %{\"slug\" => \"favorite/cat/pictures\"}\n\nThe `pipe` argument may be either:\n\n- a module that implements the `Orbit.Pipe` behaviour\n- a 2-arity function capture that accepts the request and an argument\n\nIf no route matches the request path, the router responds with a `:not_found` status.","ref":"Orbit.Router.html#route/3"},{"type":"module","title":"Orbit.Static","doc":"Serve static content from \"priv/\".\n\nThe `:path` or `*path` URL parameter must be specified when defining the route, e.g.\n\n    route \"/static/*path\", Orbit.Static, from: :my_app","ref":"Orbit.Static.html"},{"type":"module","title":"Options - Orbit.Static","doc":"- `:from` (required) - the name of the OTP application where the static files are located\n- `:dir` - the name of the directory within priv/ where the static files are located; defaults to \"static\"","ref":"Orbit.Static.html#module-options"},{"type":"function","title":"Orbit.Static.call/2","doc":"","ref":"Orbit.Static.html#call/2"},{"type":"module","title":"OrbitTest","doc":"Test helpers.","ref":"OrbitTest.html"},{"type":"function","title":"OrbitTest.body/1","doc":"Returns the response body as a binary.\n\nReturns `nil` if the status was not a success.","ref":"OrbitTest.html#body/1"},{"type":"function","title":"OrbitTest.build_client_cert/2","doc":"Returns a new self-signed `Orbit.ClientCertificate` for testing.","ref":"OrbitTest.html#build_client_cert/2"},{"type":"function","title":"Options - OrbitTest.build_client_cert/2","doc":"- `:days` - the number of days of validity; defaults to 1 day","ref":"OrbitTest.html#build_client_cert/2-options"},{"type":"function","title":"OrbitTest.meta/1","doc":"Returns the response meta field.","ref":"OrbitTest.html#meta/1"},{"type":"function","title":"OrbitTest.request/3","doc":"Performs a request and returns the processed request.\n\nIf `path_or_url` begins with `\"/\"`, a path is assumed and the requested URL becomes `\"gemini://localhost/ \"`.","ref":"OrbitTest.html#request/3"},{"type":"function","title":"Options - OrbitTest.request/3","doc":"- `:client_cert` - the client certificate, which can be constructed with `build_client_cert/2`\n- `:query` - the URL query string, or key/value pairs as a map or keyword list","ref":"OrbitTest.html#request/3-options"},{"type":"function","title":"OrbitTest.status/1","doc":"Returns the response status code as an atom.","ref":"OrbitTest.html#status/1"},{"type":"function","title":"OrbitTest.tls_request/3","doc":"Performs a full request to a Gemini server over TLS\n\nIf the `uri` begins with \"/\", a path is assumed and the requested URL becomes `\"gemini:// :  \"`.","ref":"OrbitTest.html#tls_request/3"},{"type":"function","title":"Options - OrbitTest.tls_request/3","doc":"- `:port` - the port to connect to; defaults to `1965`\n- `:ssl` - the SSL options, passed on to `:ssl.connect/3`","ref":"OrbitTest.html#tls_request/3-options"},{"type":"extras","title":"Readme","doc":"# 🪐 Orbit - a Gemini app framework for Elixir\n\n[![Module Version](https://img.shields.io/hexpm/v/orbit.svg)](https://hex.pm/packages/orbit)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/orbit/)\n\nA simple framework for a simple protocol.\n\nOrbit is a framework for building [Gemini](https://geminiprotocol.net/) applications, known as \"capsules\".\n\nThis framework focuses primarily on the Gemini protocol itself, intent on getting a request into your application,\nhandling it, and sending a Gemtext response.\n\nIt doesn't make any assumptions about your business logic, backing database, migrations, or anything like that.\nIf you need a database, you can add it manually.","ref":"readme.html"},{"type":"extras","title":"Concepts - Readme","doc":"Orbit borrows a lot of ideas from Plug and Phoenix.\n\n- `Orbit.Endpoint` - the TLS server that accepts incoming requests (`Phoenix.Endpoint` + `cowboy`)\n- `Orbit.Request` - encapsulates the request-response lifecyle (`Plug.Conn`)\n- `Orbit.Pipe` - the behaviour for request middleware (`Plug`)\n- `Orbit.Router` - defines pipelines and routes (`Phoenix.Router`)\n- `Orbit.Controller` - processes requests (`Phoenix.Controller`)\n- `Orbit.Gemtext` - renders Gemtext templates (`Phoenix.Component`)\n\nSome additional niceties:\n\n- `Orbit.Static` - serves up files from `priv/statc` (`Plug.Static`)\n- `Orbit.Status` - a canonical list of all status codes\n- `Orbit.ClientCertificate` - extracts client certificates from the request","ref":"readme.html#concepts"},{"type":"extras","title":"Installation - Readme","doc":"Orbit can be added to a new or existing application, including a Phoenix one.\n\nSee the [quickstart](https://hexdocs.pm/orbit/Orbit.html#module-quickstart) guide for installation instructions.","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Orbit Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"- Add `X509` dependency and new `Orbit.ClientCertificate` struct\n- Improve `OrbitTest` for client certificates, etc.\n- Improve `Orbit.Static` to serve up `index.gmi` files when they exist\n- Drop generated status functions from `Orbit.Status`\n- Add `mix orbit.server` (MVP, still needs some work)\n- Change path of self-signed cert in `mix orbit.gen.cert`\n- Add `embed_templates/1` to formatter export","ref":"changelog.html#v0-2-1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}